<?php
/**
 * Theme functions and definitions
 *
 * @package TwentyTen Allure
 * @since TwentyTen Allure 2.0
 */


// Set the maximum image width to avoid over floating
if ( ! isset( $content_width ) ) $content_width = 730;


/**
 * Add custom favicon and custom scripts to theme header.
 */
function wpshed_header_scripts() {
    echo '<!--[if lt IE 9]><script src="http://html5shim.googlecode.com/svn/trunk/html5.js"></script><![endif]-->';
}
add_action( 'wp_head', 'wpshed_header_scripts' );



/**
 * Add custom favicon and custom scripts to theme header.
 */
function allure_header(){

    define( 'HEADER_IMAGE_WIDTH', apply_filters( 'twentyten_header_image_width', 1140 ) );
    define( 'HEADER_IMAGE_HEIGHT', apply_filters( 'twentyten_header_image_height', 140 ) );
    define( 'HEADER_IMAGE', '' );

    add_theme_support( 'custom-background', array( 'default-color' => 'F6F3EE', ) );

}
add_action( 'after_setup_theme', 'allure_header' );



/**
 * Remove the default header images
 */
function allure_remove_twenty_ten_headers(){
    unregister_default_headers( array(
        'berries',
        'cherryblossom',
        'concave',
        'fern',
        'forestfloor',
        'inkwell',
        'path',
        'sunset')
    );
}
add_action( 'after_setup_theme', 'allure_remove_twenty_ten_headers', 11 );



/**
 * Child theme default translations
 */
class allure_translations {

    function site_generator( $translation, $text, $domain ) {
        $translations = &get_translations_for_domain( $domain );
        if ( $text == 'Proudly powered by %s.' )
            return $translations->translate( 'Powered by %s</a> &middot; a <span id="wpshed-link"><a href="http://wpshed.com" title="wordpress themes">WPshed</a> design</span>' );

        return $translation;
    }

    function comments_closed( $translation, $text, $domain ) {
        $translations = &get_translations_for_domain( $domain );
        if ( $text == 'Comments are closed.' )
            return $translations->translate( '' );

        return $translation;
    }

    function leave_reply($translation, $text, $domain) {
        $translations = &get_translations_for_domain( $domain );
        if ( $text == 'Leave a Reply' )
            return $translations->translate( 'Speak Your Mind' );

        return $translation;
    }

    function filed_under($translation, $text, $domain) {
        $translations = &get_translations_for_domain( $domain );
        if ( $text == 'This entry was posted in %1$s and tagged %2$s. Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.' )
            return $translations->translate( 'Filed under: %1$s Tagged with: %2$s. - <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.' );

        return $translation;
    }

    function filed_under_no_tag( $translation, $text, $domain ) {
        $translations = &get_translations_for_domain( $domain );
        if ( $text == 'This entry was posted in %1$s. Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.' )
            return $translations->translate( 'Filed under: %1$s. Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.' );

        return $translation;
    }

    function mobile_menu( $translation, $text, $domain ) {
        $translations = &get_translations_for_domain( $domain );
        if ( $text == 'Skip to content' )
            return $translations->translate( 'Menu' );

        return $translation;
    }


}
add_filter( 'gettext', array( 'allure_translations', 'site_generator' ), 10, 4 );
add_filter( 'gettext', array( 'allure_translations', 'comments_closed' ), 10, 4 );
add_filter( 'gettext', array( 'allure_translations', 'leave_reply' ), 10, 4 );
add_filter( 'gettext', array( 'allure_translations', 'filed_under' ), 10, 4 );
add_filter( 'gettext', array( 'allure_translations', 'filed_under_no_tag' ), 10, 4 );
add_filter( 'gettext', array( 'allure_translations', 'mobile_menu' ), 10, 4 );



/**
 * Content end excerpt read more link hacks
 */
function allure_more_link( $more_link, $more_link_text ) {
    global $post;
	return '<a href="'.get_permalink($post->ID).'" class="read-more">' . __( 'Continue Reading' ) . '</a>';
}
add_filter( 'the_content_more_link', 'allure_more_link', 10, 2 );


/**
 * Turn off comments and pingbacks by default for pages
 */
function default_comments_off_for_pages ( $data ) {
    if( $data['post_type'] == 'page' && $data['post_status'] == 'auto-draft' ) {
        $data['comment_status'] = 0;
        $data['ping_status']    = 0;
    }

    return $data;
}
add_filter( 'wp_insert_post_data', 'default_comments_off_for_pages' );



/**
 * Enqueue scripts and styles
 */
function allure_scripts() {

    // Load s_adapt.js (footer)
	wp_enqueue_script( 'adapt', get_stylesheet_directory_uri() . '/js/s_adapt.min.js', array(), '', false );
    // Load menu.js (head)
	wp_enqueue_script( 'menu', get_stylesheet_directory_uri() . '/js/menu.js', array( 'jquery' ), '', true );


}
add_action( 'wp_enqueue_scripts', 'allure_scripts' );